## Class for fecundity calculations for a variable development model

setClass("VD.fec",
          representation(params = "list",
                         fecundity.function = "function",
                         derivative.functions = "list"))

setMethod("initialize", "VD.fec",
          function(.Object, fecundity.function, params = NULL, derivative.functions = NULL) {
            .Object@fecundity.function <- if(is.character(fecundity.function)) {
              eval.parent(as.name(fecundity.function));
            } else {
              fecundity.function
            }
            .Object@params <- c(list(age = as.name("age"), age.maturity = as.name("age.maturity")), params);
                       
            if(!is.null(derivative.functions)) {
              for(n in names(derivative.functions)) {
                .Object@derivative.functions[[n]] <- if(is.character(derivative.functions[[n]])) {
                  eval.parent(as.name(derivative.functions[[n]]))
                } else {
                  derivative.functions[[n]]
                }
              }
            }            
            .Object
          }
          )

VD.fec <- function(fecundity.function, params = NULL, derivative.functions = NULL ) {
  new("VD.fec", fecundity.function = fecundity.function, params = params, derivative.functions = derivative.functions);
}

VD.fec.calc <- function(age, age.maturity, VD.fec, new.params = NULL) {
  if(class(VD.fec) != "VD.fec") { stop("Error, must supply an object of class VD.fec");}

  do.new.params <- !is.null(new.params);
  if(!do.new.params) {
    return(do.call(VD.fec@fecundity.function, VD.fec@params));
  }
  updated.params <- VD.fec@params;
  replace.indices <- match(names(new.params), names(updated.params), 0)
  updated.params[replace.indices] <- new.params[replace.indices > 0];
  return(do.call(VD.fec@fecundity.function, updated.params))
}

VD.fec.deriv <- function(age, age.maturity, VD.fec, param, force.numerical = FALSE, delta = 0.0001) {
  do.numerical <- TRUE;
  if(!force.numerical) {
    do.numerical <- !(param %in% names(VD.fec@derivcalls));
  }
  if(!do.numerical) {
    newcall <- VD.fec@derivcalls[[param]];
    newcall[[2]] <- as.name("age");
    newcall[[3]] <- as.name("age.maturity");
    return(eval(newcall));
  }
  new.params <- list();
  new.params[[param]] <- VD.fec@params[[param]] + delta;
  ans <- (VD.fec.calc(age, age.maturity, VD.fec, new.params = new.params) - VD.fec.calc(age, age.maturity, VD.fec)) / delta;
  return(ans);
}
