## Variable Development Model class

setClass("VD.model",
         representation(num.stages = "integer",
                        stage.names = "character",
                        stage.independent = "logical",
                        all.independent = "logical",
                        gauss.cov = "matrix",
                        gauss.inv.cov = "matrix",
                        det.cov = "numeric",
                        marginal.duration.dists = "list",
                        marginal.death.time.dists = "list",
                        fecundity = "VD.fec",
                        controls = "data.frame"))

marginal.durations <- function(VDM) {
  warning("marginal.durations expects VDM to be a VD.model");
}
`marginal.durations<-` <- function(VDM, value) {
  warning("marginal.durations<- expects VDM to be a VD.model");
}
setGeneric("marginal.durations")

setMethod("marginal.durations", "VD.model",
          function(VDM) {
            VDM@marginal.duration.dists
          })
setReplaceMethod("marginal.durations", signature(VDM = "VD.model"),
          function(VDM, value) {
            VDM@marginal.duration.dists <- value
            VDM
            }
          )

marginal.death.times <- function(VDM) {
  warning("marginal.death.times expects VDM to be a VD.model");
}

`marginal.death.times<-` <- function(VDM, value) {
  warning("marginal.death.times<- expects VDM to be a VD.model");
}
setGeneric("marginal.death.times")

setMethod("marginal.death.times", "VD.model",
          function(VDM) {
            VDM@marginal.death.time.dists
          })
setReplaceMethod("marginal.death.times", signature(VDM = "VD.model"),
          function(VDM, value) {
            VDM@marginal.death.time.dists <- value
            VDM
            }
          )

fecundity <- function(VDM) {
  warning("fecundity expects VDM to be a VD.model");
}
`fecundity<-` <- function(VDM, value) {
  warning("fecundity<- expects VDM to be a VD.model");
}
setGeneric("fecundity")

setMethod("fecundity", "VD.model",
          function(VDM) {
            VDM@fecundity
          })
setReplaceMethod("fecundity", signature(VDM = "VD.model"),
          function(VDM, value) {
            VDM@fecundity <- value
            VDM
            }
          )

controls <- function(VDM) {
  warning("controls expects VDM to be a VD.model");
}
`controls<-` <- function(VDM, value) {
  warning("controls<- expects VDM to be a VD.model");
}
setGeneric("controls")

setMethod("controls", "VD.model",
          function(VDM) {
            VDM@controls
          })
setReplaceMethod("controls", signature(VDM = "VD.model"),
          function(VDM, value) {
            VDM@controls <- value
            VDM
            }
          )

gauss.cov <- function(VDM) {
  warning("gauss.cov expects VDM to be a VD.model");
}
setGeneric("gauss.cov")
setMethod("gauss.cov", "VD.model",
          function(VDM) {
            VDM@gauss.cov
          })

stage.independent <- function(VDM) {
  warning("stage.independent expects VDM to be a VD.model");
}
setGeneric("stage.independent")
setMethod("stage.independent", "VD.model",
          function(VDM) {
            VDM@stage.independent
          })

all.independent <- function(VDM) {
  warning("all.independent expects VDM to be a VD.model");
}
setGeneric("all.independent")
setMethod("all.independent", "VD.model",
          function(VDM) {
            VDM@all.independent
          })

num.stages <- function(VD) {
  warning("num.stages expects VD to be a VD.model");
}
setGeneric("num.stages")
setMethod("num.stages", "VD.model",
          function(VD) {
            VD@num.stages
          })

stage.names <- function(VD) {
  warning("stage.names expects VD to be a VD.model");
}
`stage.names<-` <- function(VD, value) {
  warning("stage.names<- expects VD to be a VD.model");
}
setGeneric("stage.names")

setMethod("stage.names", "VD.model",
          function(VD) {
            VD@stage.names
          })
setReplaceMethod("stage.names", signature(VD = "VD.model"),
          function(VD, value) {
            VD@stage.names <- value
            VD
            }
          )


setMethod("initialize", "VD.model",
          function(.Object, num.stages, marginal.durations, marginal.death.times, fecundity = NULL,
                   controls = NULL, stage.names = NULL, gauss.cov = NULL) {
             
            if(is.null(fecundity)) {writeLines("Warning: no fecundity specified.  You can simulate development and survival, but you will need to specific fecundity to find population growth rate and other results.");}

            .Object@num.stages <- as.integer(num.stages)
            if(is.null(stage.names)) stage.names <- paste("Stage", 1:num.stages, sep = "");
            .Object@stage.names <-stage.names
  
            .Object@all.independent <-is.null(gauss.cov)
            if(!.Object@all.independent) {
              if(ncol(gauss.cov) != nrow(gauss.cov)) {stop("Error: gauss.cov must be a square matrix");}
              if(any(diag(gauss.cov) != 1)) {stop("Error: gauss.cov must have 1's on the diagonal");}
              .Object@gauss.cov <- gauss.cov
              .Object@gauss.inv.cov <- solve(gauss.cov);
              .Object@det.cov <- det(gauss.cov);
            }
            .Object@stage.independent <- c(TRUE, rep(.Object@all.independent, num.stages - 1)); # can be improved to pick out independent stages.
  
            .Object@marginal.duration.dists <- marginal.durations;
            .Object@marginal.death.time.dists <- marginal.death.times;

            if(class(fecundity) %in% c("numeric", "integer")) {
              .Object@fecundity <- VD.fec(VD.fecundity.constant, list(m = fecundity))
            } else { 
              if(!is.null(fecundity)) .Object@fecundity <- fecundity;
            }
            
            if(!is.null(controls)) {
              .Object@controls <- controls;
            } else {
              .Object@controls <- VD.controls(num.stages);
            }
            .Object
          }
          )

VD.controls <- function(num.stages, batch.size = 5000, alive.target = 10000, dead.target =  c(rep(10000, num.stages - 1), 0), max.dead = 20000, max.total = 100000, ragged.save = TRUE) {
  ans <-  structure(data.frame(matrix(nrow = num.stages, ncol = 6)), names = c("batch.size", "alive.target", "dead.target", "max.dead", "max.total", "ragged.save"))  
  ans[,"batch.size"] <- if(length(batch.size) == 1) rep(batch.size, num.stages) else batch.size;
  ans[,"alive.target"] <-  if(length(alive.target) == 1) rep(alive.target, num.stages) else alive.target;
  ans[,"dead.target"] <- if(length(dead.target) == 1) rep(dead.target, num.stages) else dead.target;
  ans[,"max.dead"] <- if(length(max.dead) == 1) rep(max.dead, num.stages) else max.dead;
  ans[,"max.total"] <- if(length(max.total) == 1) rep(max.total, num.stages) else max.total;
  ans[,"ragged.save"] <- if(length(ragged.save) == 1) rep(ragged.save, num.stages) else ragged.save;
  ans
}

VD.model <- function(num.stages, marginal.durations, marginal.death.times, fecundity = NULL, controls = NULL, stage.names = NULL, gauss.cov = NULL) {
  if(class(marginal.durations) != "list") {stop("Error: marginal.durations should be a list");}
  if(length(marginal.durations) != num.stages) {stop("Error: length(marginal.durations) should equal num.stages");}
  if(class(marginal.death.times) != "list") {stop("Error: marginal.death.times should be a list");}
  if(length(marginal.death.times) != num.stages) {stop("Error: length(marginal.death.times) should equal num.stages");}
            
  new("VD.model", num.stages, marginal.durations, marginal.death.times, fecundity, controls, stage.names, gauss.cov);
}

setClass("VD.sim",
         representation(simulation.summary = "data.frame",
                        stageMC = "list",
                        stage.names = "character", 
                        num.stages = "integer"))

setMethod("initialize", "VD.sim",
          function(.Object, VDM) {
            if(class(VDM) == "VD.model") {
              .Object@num.stages <- VDM@num.stages
              .Object@stage.names <- VDM@stage.names
            } else {
              .Object@num.stages <- as.integer(VDM);
              .Object@stage.names <- paste("Stage", 1:.Object@num.stages, sep = "");
            }
            .Object@simulation.summary <- structure(data.frame(matrix(nrow = .Object@num.stages, ncol = 7)),
                                           names = c("Stage",
                                             "prob.surv.stage",
                                             "total.count",
                                             "total.alive",
                                             "total.dead",
                                             "discarded.alive",
                                             "discarded.dead"))
            
            .Object@stageMC <- list();
            .Object
          }
          )

setMethod("num.stages", "VD.sim",
          function(VD) {
            VD@num.stages
          })

setMethod("stage.names", "VD.sim",
          function(VD) {
            VD@stage.names
          })

simulation.summary <- function(VDS) {
  warning("simulation.summary expects VDS to be a VD.sim");
}
setGeneric("simulation.summary")
setMethod("simulation.summary", "VD.sim",
          function(VDS) {
            VDS@simulation.summary
          })
`simulation.summary<-` <- function(VDS, value) {
  warning("simulation.summary<- expects VDS to be a VD.sim");
}
setReplaceMethod("simulation.summary", signature(VDS = "VD.sim"),
          function(VDS, value) {
            VDS@simulation.summary <- value
            VDS
            }
          )


stageMC <- function(VDS) {
  warning("stageMC expects VDS to be a VD.sim");
}
setGeneric("stageMC")
setMethod("stageMC", "VD.sim",
          function(VDS) {
            VDS@stageMC
          })

`stageMC<-` <- function(VDS, value) {
  warning("stageMC<- expects VDS to be a VD.sim");
}
setReplaceMethod("stageMC", signature(VDS = "VD.sim"),
          function(VDS, value) {
            VDS@stageMC <- value
            VDS
            }
          )

VD.sim <- function(VDM) {
  new("VD.sim", VDM)
}

setClass("VD.SASD", contains = "list");
as.VD.SASD <- function(x) {as(x, "VD.SASD");}
setMethod("plot", "VD.SASD",
          function(x, y, age.vector, two.axes, two.axes.threshold, use.right.axis,
                   main = "Stable age-stage distribution",
                   xlab = "Age",
                   ylab="Stable age-stage fraction",
                   left.lty = "solid",
                   right.lty = "dotted",
                   left.col = "black",
                   right.col = left.col,
                   right.axis.factor = 1,
                   lwd = 1, add = FALSE,  ...) {
            if(missing(age.vector)) {
              age.vector <- x$age.vector;
            }

            i.max.age <- length(age.vector);
            num.stages <- dim(x$SASD)[2];
            scale.factors <- rep(1, num.stages);
            ltys <- rep(left.lty, num.stages);
            cols <- rep(left.col, num.stages);
            stage.peaks <- apply(x$SASD[1:i.max.age,], 2, max);
            
            if(!add) {
              range.peaks <- range(stage.peaks);
              if(missing(two.axes.threshold))
                if(missing(right.axis.factor)) two.axes.threshold <- 4 else two.axes.threshold <- right.axis.factor - 0.00000001;
              if(missing(two.axes)) two.axes <- (range.peaks[2] / range.peaks[1] >= two.axes.threshold)
               
              if(two.axes) {
                if(missing(use.right.axis)) {
                  largest.small.peak <- max(stage.peaks[ range.peaks[2] / stage.peaks  >= two.axes.threshold])
                  use.right.axis <- stage.peaks <= largest.small.peak
                  if(missing(right.axis.factor)) right.axis.factor <- range.peaks[2] / largest.small.peak;
                } else {
                  if(missing(right.axis.factor)) right.axis.factor <- range.peaks[2] / max(stage.peaks[use.right.axis]);
                }
                ltys[use.right.axis] <- right.lty;
                cols[use.right.axis] <- right.col;
                scale.factors[use.right.axis] <- right.axis.factor;              
                par(mar = c(5,4,4,4) + 0.1);
              }
              plot(range(age.vector), c(0, range.peaks[2]), type = "n", main = main, xlab = xlab, ylab = ylab)
              if(two.axes) {
                axvals <- pretty(par("usr")[3:4] / right.axis.factor);
                axis(side = 4, at = axvals * right.axis.factor, labels = axvals)
              }
            } else {
              
              y.range <- par()$usr[3:4];
              y.max <- y.range[2] - (diff(y.range)*(1 - 1/1.08))/2
              if(!missing(right.axis.factor)) {
                if(missing(use.right.axis)) {
                  use.right.axis <- stage.peaks <= y.max / right.axis.factor;
                }
                scale.factors[use.right.axis] <- right.axis.factor;  
                ltys[use.right.axis] <- right.lty;
                cols[use.right.axis] <- right.col;
              }
            }
            for(i.stage in 1:num.stages) {
              points(age.vector, x$SASD[1:i.max.age, i.stage]*scale.factors[i.stage], type = "l", lty = ltys[i.stage], col = cols[i.stage], lwd = lwd)
            }
            right.axis.factor
          })

VD.mean.age <- function(SASD) {
  writeLines(paste("Warning: you should not be getting to default VD.mean.age method"))
}
setMethod("VD.mean.age", "VD.SASD",
          function(SASD) {
            apply( SASD$SASD, 2, function(x) {sum(x * SASD$age.vector)} ) / SASD$SSD;
          })

VD.mode.age <- function(SASD) {
  writeLines(paste("Warning: you should not be getting to default VD.mode.age method"))
}

setMethod("VD.mode.age", "VD.SASD",
          function(SASD) {
            SASD$age.vector[apply( SASD$SASD, 2, which.max)]
          })

