\name{VD.calc.conditional.info}
\alias{VD.calc.conditional.info}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Calculate conditional Gaussian means and variance for copula model of correlated stage durations}
\description{
  When a stochastic (or variable) development model uses correlated stage durations defined by a Gaussian copula, the mean and variance of one dimension given the previous dimensions are needed. This function calculates those.  These cannot be pre-calculated because of the sequential Monte Carlo steps, which mean that only the survivors of stage 1 are used for stage 2, and so on.
}
\usage{
VD.calc.conditional.info(VDM, VDS, iS)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{VDM}{Model definition object of class \code{\link{VD.model}}}
  \item{VDS}{Sequential Monte Carlo simulation result of class \code{\link{VD.sim}} of model \code{VDM}, typically generated by \code{\link{VD.run}} with simulation results through at least stage \code{iS}}
  \item{iS}{Stage index for which conditional information is desired}
}
\details{
  Uses the first \code{iS} rows and columns of the Gaussian covariance matrix defined in VDM.  Calculates the means (for each simulation in \code{VDS} that survives to stage \code{iS}) and variance (the same value for all) of the \code{iS} dimension of the standard normal marginal deviates that define the quantiles of the stage durations.

  This is not typically called by the user.  It is used mainly by \code{\link{VD.run.stage}} and also by \code{\link{VD.solve.fraction.maturing.at.SASD.mc}}.
}
\value{
  A list containing:
  \item{conditional.means}{Vector of conditional means}
  \item{conditional.var}{Conditional variance}
  \item{conditional.sd}{Conditional standard deviation}
  \item{num.alive}{Number of simulations in \code{VDS} that survive to stage \code{iS}}
}
\references{ "Stochastic development in biologically structured population models" by Perry de Valpine, to appear in Ecology in 2009. }
\author{Perry de Valpine}
% \note{ ~~further notes~~ 

%  ~Make other sections like Warning with \section{Warning }{....} ~
% }
\seealso{\code{\link{VD.model}}, \code{\link{VD.sim}}. Introduction and examples can be found by \code{vignette("varDev")}.}

