\name{VD.deriv.euler}
\alias{VD.deriv.euler}
\alias{VD.deriv.growth.rate}
\alias{VD.deriv.euler.dr}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Calculate derivatives of the Monte Carlo approximation to the Euler equation and of population growth rate  }
\description{
  The solution to the Euler equation gives the long-term population growth rate. Derivatives of population growth rate are needed for the demographic sensitivities.   These derivatives are done by implicit differentiation, using the derivatives of the Euler equation with respect to r and with respect to a parameter of the variable development model.  The latter can be calculated for  any model parameter, using a numerical derivative if necessary.  Derivatives involving copula models are no implemented yet.
}

\usage{
VD.deriv.growth.rate(VDM, r, dev.table, fecundity.by.age, stage = NULL, death = NULL, fecundity = NULL, param = NULL, force.numerical = FALSE, make.discrete = FALSE, delta = NULL, F = NULL)
VD.deriv.euler(VDM, r, dev.table, fecundity.by.age, stage = NULL, death = NULL, fecundity = NULL, param = NULL, force.numerical = FALSE, make.discrete = FALSE, delta = NULL, F = NULL)
VD.deriv.euler.dr(r, fecundity.by.age)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{VDM}{ A variable development model object of class \linkS4class{VD.model}.}
  \item{r}{ Long-term population growth rate (i.e. solution to the Euler equation), typically obtained by \code{\link{VD.solve.euler}}. }
  \item{dev.table}{ Development table for model \code{VDM} obtained from sequential Monte Carlo simulation, typically obtained by \code{make.dev.table} with the results of \code{VD.run(VDM)}}
  \item{fecundity.by.age}{ Data frame returned by \code{calc.average.surv.rep.by.age}}
  \item{stage}{ If non-NULL, an integer indicating which stage duration distribution has the parameter for the derivative. \emph{Only one of \code{stage}, \code{survival}, or \code{fecundity}  should be non-NULL.}}
  \item{death}{ If non-NULL, an integer indicating which age-within-stage of death distribution has the parameter for derivative}
  \item{fecundity}{ If non-NULL, derivative is for a parameter of the fecundity distribution (actual value of \code{fecundity} is not used, just whether or not it is NULL).}
  \item{param}{ Character string naming a parameter with respect to which the derivative should be calculated.}
  \item{force.numerical}{ If \code{TRUE}, use a numerical derivative even if a derivative function is known by \code{VDM}.0}
  \item{make.discrete}{ If \code{TRUE}, force the values in the dev.table to be discretized to integers and derivative to be done appropriately.  }
  \item{delta}{ Small change in parameter value to be used for numerical derivative.  If \code{NULL}, a default used by the \linkS4class{VD.dist} or \linkS4class{VD.fec} objects in \code{VDM} is used.}
  \item{F}{ If \code{fecundity} is non-NULL, an object of class \code{VD.fec} or a number for constant adult fecundity.  This is passed to \code{\link{calc.average.surv.rep.by.age}}. }
}
\details{
\code{VD.deriv.growth.rate} gives the derivative of population growth rate by implicit differentiation as the negative of the ratio of \code{VD.deriv.euler} and \code{VD.deriv.euler.dr}.

\code{VD.deriv.euler} gives the derivative of population growth rate, r, with respect to any parameter of a stage duration distribution, age-within-stage of death distribution, or the fecundity model in \code{VDM}.

\code{VD.deriv.euler.dr} gives the derivative of the Euler equation with respect to r, the population growth rate, evaluated at the value of r that solves the equation.

  For derivatives with respect to stage duration and death distribution parameters, \code{VD.deriv.euler} calls \code{\link{VD.dist.deriv}}. 
}
\value{
  A number giving the requested derivative.
}
\section{Warning}{Derivatives involving copula models are not yet implemented.}
\references{"Stochastic development in biologically structured population models" by Perry de Valpine, to appear in Ecology in 2009.}
\author{ Perry de Valpine}
\seealso{ Introduction and examples can be found by \code{vignette("varDev")}. }

