\name{VD.dist-class}
\docType{class}
\alias{VD.dist-class}
\alias{initialize,VD.dist-method}
\alias{plot,ANY,VD.dist-method}
\alias{plot,VD.dist,ANY-method}

\title{Class "VD.dist" }
\description{Represents probability distributions for use by stochastic (or variable) development model simulations.  Contains a call to each of a "p", "d", "q", and "r" distribution function (see basic \R documentation, such as \code{?dnorm}), with parameters fixed.  These calls can be run by methods \code{VD.dist.calc} and \code{VD.dist.deriv}, which have facilities for changing parameters, obtaining a numerical derivative, and discretizing continuous random variables to integers (by rounding up).  Discrete distributions represented by \code{VD.dist} objects must have support on (1, 2, 3, ...), not (0, 1, 2, 3, ...).  This suits the definitions of variable development models but differs from standard distributions.  See \link{dgeomp1}.  }
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("VD.dist", distribution.name, params = NULL, pdf.derivs = NULL, cdf.derivs = NULL, quantile.derivs = NULL)}.

A wrapper function \code{\link{VD.dist}(distribution.name, params, pdf.derivs, cdf.derivs, quantile.derivs)} is also available.

See \code{\link{VD.dist}} for full description of arguments.  Note that \code{distribution.name} \emph{omits} the "p", "d", "q", or "r", and the class \emph{requires} that some or all of these (depending on how it will be used) be defined with the same arguments, as is standard for \R's usual distribution functions.
}
\section{Slots}{
	 \describe{
    \item{\code{params}:}{A \code{list} object whose names are arguments names needed by the distribution functions and whose values are the corresponding argument values.}
    \item{\code{distribution.functions}:}{A \code{list} object with components "pdf", "cdf", "random" and "quantile" containing function objects for respective the "p", "d", "q" and "r" functions.}
    \item{\code{deriv.functions}:}{A \code{list} object with any of components "pdf", "cdf", and/or "quantile" containing lists named by parameters with \code{function} objects that calculate derivatives for those parameters.  These must have been supplied explicitly by the user.  If the class does not find a derivative function for a parameter, it will obtain a derivative numerically.}
  }
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "VD.dist")}: Sets up all the call objects for future use.  Does not do much checking. }
    \item{plot}{\code{signature(x = "ANY", y = "VD.dist")}: Plots the pdf (or cdf, if "cdf = TRUE") of the discretized distribution. }
    \item{plot}{\code{signature(x = "VD.dist", y = "ANY")}: Plots the pdf (of cdf, if "cdf = TRUE") of the discretized distribution. }

	 }
}
\references{"Stochastic development in biologically structured population models" by Perry de Valpine, to appear in Ecology in 2009.}
\author{Perry de Valpine}

\seealso{
	\code{\link{VD.dist.calc}}, \code{\link{VD.dist.deriv}}, \code{link{dgeomp1}}, \code{\link{dinfinite}}. Introduction and examples can be found by \code{vignette("varDev")}.
}


