\name{VD.dist.calc}
\alias{VD.dist.calc}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Do distribution calls for a VD.dist object}
\description{
  \code{VD.dist} objects contain calls to a family of distribution functions organized in the usual way as "p", "d", "q", and "r" functions for cumulative, density, quantile, and random, respectively (e.g. \code{pnorm}, \code{dnorm}, \code{qnorm}, and \code{rnorm}) with fixed (but adjustable) parameters.  \code{VD.dist.calc} is the interface for calling the functions managed by a \code{VD.dist} object.  For the stochastic (or variable) development models, this provides a way to encapsulate a model definition that a model component follows a particular distribution.  It also handles discretization of continuous distributions.
}
\usage{
VD.dist.calc(x, distr, calc, make.discrete = FALSE, new.params = NULL)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{The object to be passed as the  \emph{first} argument to any of the distribution functions, regardless how the first argument is named in those functions.  For example, the first argument to \code{qnorm} is \code{p}, but here it is passed as \code{x} (but named \code{p} is the subsequent call to \code{qnorm} generated by the \code{VD.dist} object \code{distr}).}
  \item{distr}{An object of class \code{VD.dist} that knows what distribution functions to call.}
  \item{calc}{One of "pdf", "cdf", "quantile", or "random", corresponding to whichever function should be called.}
  \item{make.discrete}{If \code{TRUE}, treat the distribution as having domain of the integers, \strong{starting at 1}.  For continuous distributions, the probability of \code{x} is treated as the integral from \code{floor(x)} to \code{ceiling(x)}.  This has no effect when \code{calc} is "quantile" or "random".}
  \item{new.params}{An optional list of parameters to replace or add in the parameter list of \code{distr}.  For example, \code{new.params = list(lower.tail = FALSE)} would either change (if already present) or insert (if not present) the \code{lower.tail} argument as \code{FALSE} in the call generated to the "d", "p", "q", or "r" function.}
}
\value{
	Whatever would normally be returned by a call the the "p", "d", "q" or "r" function.  For example, if \code{distr = \link{VD.dist}(norm(mean = 5, sd = 2))}, then \code{VD.dist.calc} with \code{calc = "quantile"} returns whatever is returned by \code{qnorm}.
}
\seealso{\code{\link{VD.dist.deriv}}. Introduction and examples can be found by \code{vignette("varDev")}.}
\references{"Stochastic development in biologically structured population models" by Perry de Valpine, to appear in Ecology in 2009.}
\author{Perry de Valpine}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.

