\name{VD.fec-class}
\docType{class}
\alias{VD.fec-class}
\alias{initialize,VD.fec-method}

\title{Class "VD.fec"  }
\description{A class for fecundity calculations as a function of age and/or age-at-maturity for stochastic (or variable) development models.  Objects of this class hold functions and parameters for the fecundity calculations (to be accessed using \code{\link{VD.fec.calc}}) and possibly for derivatives of fecundity (to be called using \code{\link{VD.fec.deriv}}) with respect to parameters.  Derivative can be calculated numerically even if appropriate functions are not given.}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("VD.fec", fecundity.function, params = NULL, derivative.functions = NULL)}.
	
A wrapper for this is \code{\link{VD.fec}(fecundity.function, params = NULL, derivative.functions = NULL)}.  See that help page for details of how the fecundity functions should be set up.
}
\section{Slots}{
	 \describe{
    \item{\code{params}:}{Object of class \code{"list"} whose names are parameters of the fecundity (and derivative) functions and whose values are the parameter values.  }
    \item{\code{fecundity.function}:}{\code{function} object that must take \code{age} as a first argument and \code{age.at.maturity} as a second argument, and anything else in \code{params} as further arguments. }
    \item{\code{derivative.functions}:}{\code{list} object (may be NULL) whose names are parameters of the fecundity function and whose contents are calls to functions that calculate the derivatives.  The \code{VD.fec} class also knows how to calculate derivatives numerically. }
  }
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "VD.fec")}: ... }
	 }
}
\references{"Stochastic development in biologically structured population models" by Perry de Valpine, to appear in Ecology in 2009.}
\author{Perry de Valpine}
\section{Warning}{Little or no checking of the validity of arguments is done by \code{initialize}.} 
\note{ The general approach of \code{VD.fec} is similar to that of \code{\linkS4class{VD.dist}}. }

\seealso{
	\code{\linkS4class{VD.dist}}, \code{\link{VD.fec.calc}}, \code{\link{VD.fec.deriv}}, \code{VD.fec} for details of how the fecundity functions should be set up. Introduction and examples can be found by \code{vignette("varDev")}.
}

