\name{VD.fec.calc}
\alias{VD.fec.calc}
\alias{VD.fec.deriv}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Do fecundity calculations for stochastic (or variable) development model using a VD.fec object}
\description{
  \code{VD.fec} objects encapsulate the fecundity model used for a stochastic development model, allowing its parameters to be set up once, re-used, and manipulated such as for numerical derivatives.  \code{VD.fec.calc} is the main function to use a \code{VD.fec} object to calculate fecundities.  \code{VD.fec.deriv} calculates derivatives.
}
\usage{

VD.fec.calc(age, age.maturity, VD.fec, new.params = NULL)

VD.fec.deriv(age, age.maturity, VD.fec, param, force.numerical = FALSE, delta = 1e-04)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{age}{Vector of ages for which fecundity should be calculated.  This is passed as the first argument to the fecundity functions managed by \code{VD.fec}.}
  \item{age.maturity}{Vector of ages of maturity for which fecundity should be calculated.  This is aligned with \code{age}.  This is passed as the second argument to the fecundity functions managed by \code{VD.fec}.}
  \item{VD.fec}{ An object of class \code{\linkS4class{VD.fec}} }
  \item{new.params}{ Optional list of replacement parameters, with names that are parameter names. (Unlike the similar \code{\link{VD.fec.calc}}, this does not allow new parameters to be inserted.  It could, but this has not been needed.)}
  \item{param}{Character string of the parameter name with respect to which the derivative should be taken.}
  \item{force.numerical}{If \code{TRUE}, the derivative will be done numerically even if a derivative function is available to the \code{VD.fec} object.}
  \item{delta}{ Small value to be added to the parameter value when calculating a numerical derivative}
}
\details{
  \code{VD.fec.calc} calls the fecundity function.  

  \code{VD.fec.deriv} calls the derivative functions or calculates a numerical derivative.
}
\value{
	For \code{VD.fec.calc}, whatever is returned by the call to the fecundity function by \code{VD.fec}, which should be a vector of fecundity values aligned with the \code{age} and \code{age.maturing} vectors.  

	For \code{VD.fec.deriv}, whatever is returned by the call to the derivative function by \code{VD.fec}, or by the numerical derivative using \code{VD.fec.calc}.  In any case this should be a vector aligned with the \code{age} and \code{age.maturing} vectors.  
}
\references{"Stochastic development in biologically structured population models" by Perry de Valpine, to appear in Ecology in 2009.}
\author{ Perry de Valpine}

\seealso{\code{\linkS4class{VD.fec}}, \code{\link{VD.dist}}. Introduction and examples can be found by \code{vignette("varDev")}. }

