\name{VD.model-class}
\docType{class}
\alias{VD.model-class}
\alias{initialize,VD.model-method}
\alias{all.independent,VD.model-method}
\alias{all.independent}
\alias{controls,VD.model-method}
\alias{controls-methods}
\alias{controls,ANY-method}
\alias{controls<-,VD.model-method}
\alias{controls<-}
\alias{controls<--methods}
\alias{controls<-,ANY-method}
\alias{fecundity,VD.model-method}
\alias{fecundity,ANY-method}
\alias{fecundity-methods}
\alias{fecundity}
\alias{fecundity<-,VD.model-method}
\alias{fecundity<--methods}
\alias{fecundity<-,ANY-method}
\alias{fecundity<-}
\alias{gauss.cov,VD.model-method}
\alias{gauss.cov,ANY-method}
\alias{gauss.cov}
\alias{gauss.cov-methods}
\alias{initialize,VD.model-method}
\alias{marginal.death.times,VD.model-method}
\alias{marginal.death.times,ANY-method}
\alias{marginal.death.times-methods}
\alias{marginal.death.times}

\alias{marginal.death.times<-,VD.model-method}
\alias{marginal.death.times<-,ANY-method}
\alias{marginal.death.times<--methods}
\alias{marginal.death.times<-}

\alias{marginal.durations,VD.model-method}
\alias{marginal.durations,ANY-method}
\alias{marginal.durations-methods}
\alias{marginal.durations}

\alias{marginal.durations<-,VD.model-method}
\alias{marginal.durations<-,ANY-method}
\alias{marginal.durations<--methods}
\alias{marginal.durations<-}

\alias{num.stages,VD.model-method}
\alias{num.stages,ANY-method}
\alias{num.stages-methods}
\alias{num.stages}

\alias{stage.independent,VD.model-method}
\alias{stage.independent,ANY-method}
\alias{stage.independent-methods}
\alias{stage.independent}

\alias{stage.names,VD.model-method}
\alias{stage.names<-,VD.model-method}
\alias{stage.names<-,ANY-method}
\alias{stage.names<--methods}
\alias{stage.names<-}

\title{Class "VD.model"  }
\description{\code{VD.model} contains the model definition for a stochastic (or variable) development model of biologically stage-structured population dynamics.  It includes definitions of marginal stage duration distributions, an optional Gaussian copula distribution to define correlations among stage durations, definitions of stage-specific mortality, an optional fecundity model, and control parameters.}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("VD.model", num.stages, marginal.durations, marginal.death.times, fecundity, controls, stage.names, gauss.cov)}.

A slightlier friendlier method is provided by \code{\link{VD.model}(num.stages, marginal.durations, marginal.death.times, fecundity, controls, stage.names, gauss.cov)}
}
\section{Slots}{
	 \describe{
    \item{\code{num.stages}:}{Object of class \code{"integer"} giving the number of stages. }
    \item{\code{stage.names}:}{Vector of class \code{"character"} giving stage names.  If omitted when a new \code{VD.model} object is requested, names of "Stage1", "Stage2", etc. will be used.  If included, it must have length \code{stage.num}. }
    \item{\code{stage.independent}:}{A logical vector of length \code{num.stages} indicating whether each stage is independent of all others.  Currently, stage 1 is \emph{always} treated as independent.  Subsequent stages are treated as dependent if the model is defined with a \code{gauss.cov} matrix, even if the matrix is diagonal or has some independent entries. }
    \item{\code{all.independent}:}{A single logical vector that is \code{FALSE} if a \code{gauss.cov} matrix is included in the definition, \code{TRUE} otherwise.
    \item{\code{gauss.cov}:}{Object of class \code{"matrix"} representing the covariance matrix of the Gaussian copula.}
    \item{\code{guass.inv.cov}:}{Object of class \code{"matrix"} ~~ }
    \item{\code{det.cov}:}{Object of class \code{"numeric"} ~~ }
    \item{\code{marginal.duration.dists}:}{Object of class \code{"list"} with length \code{num.stages}.  Each component is a \code{\linkS4class{VD.dist}} object definining a marginal stage duration dustribution. }
    \item{\code{marginal.death.time.dists}:}{Object of class \code{"list"} with length \code{num.stages}. Each component is a \code{\linkS4class{VD.dist}} object definining a marginal time-of-death duration. }
    \item{\code{fecundity}:}{Object of class \code{"VD.fec"} defining the fecundity model for the adult (final) stage.  If missing, it can be supplied when functions such as \code{\link{calc.average.surv.rep.by.age}} are called.  If given as a number to the \code{initialize} method, a \code{VD.fec} object for constant fecundity is created. }
    \item{\code{controls}:}{Object of class \code{"data.frame"} defining controls on sequential Monte Carlo simulations of the \code{VD.model} by \code{VD.run.stage}.  See \code{\link{controls}}. }
  }
}}
\section{Methods}{
  \describe{
    \item{all.independent}{\code{signature(VDM = "VD.model")}: Returns TRUE if all stages of a \code{\link{VD.model}} object are independent. }
    \item{controls}{\code{signature(VDM = "VD.model")}: Returns controls data frame.  See \code{\link{controls}}. }
    \item{controls<-}{\code{signature(VDM = "VD.model")}: Assign controls data frame. }
    \item{fecundity}{\code{signature(VDM = "VD.model")}: Return the fecundity object of class \linkS4class{VD.fec} from a VD.model object }
    \item{fecundity<-}{\code{signature(VDM = "VD.model")}: Assign a fecundity object of class \linkS4class{VD.fec} to a VD.model object }
    \item{gauss.cov}{\code{signature(VDM = "VD.model")}: Return the covariance (really correlation) matrix of the Gaussia copula model for correlated stage durations. }
    \item{initialize}{\code{signature(.Object = "VD.model")}: ... }
    \item{marginal.death.times}{\code{signature(VDM = "VD.model")}: Return list of \linkS4class{VD.dist} objects defining age-within-stage of death distributions. }
    \item{marginal.death.times<-}{\code{signature(VDM = "VD.model")}: Assign list of \linkS4class{VD.dist} objects defining age-within-stage of death distributions.  }
    \item{marginal.durations}{\code{signature(VDM = "VD.model")}: Return list of \linkS4class{VD.dist} objects defining stage duration distributions. }
    \item{marginal.durations<-}{\code{signature(VDM = "VD.model")}: Assign list of \linkS4class{VD.dist} objects defining stage duration distributions. }
    \item{num.stages}{\code{signature(VD = "VD.model")}: Return the number of stages in a VD.model object. }
    \item{stage.independent}{\code{signature(VDM = "VD.model")}: Return a vector of logicals of length \code{num.stages}, each \code{TRUE} if that stage is independent.  This is not used as fully as it could be.  For a model with a non-NULL \code{gauss.cov} matrix, stage 1 is treated as independent and the rest as non-independent (even if they in fact are independent according to the \code{gauss.cov} matrix). }

    \item{stage.names}{\code{signature(VD = "VD.model")}: Return vector of stage names. }
    \item{stage.names<-}{\code{signature(VD = "VD.model")}: Assign vector of stage names. }
	 }
}
\references{"Stochastic development in biologically structured population models" by Perry de Valpine, to appear in Ecology in 2009.}
\author{Perry de Valpine}
\section{Warning}{Little or no checking of valid definitions is made during \code{VD.model} object creation.}
\seealso{
	\code{\linkS4class{VD.dist}}, \code{\linkS4class{VD.fec}}, \code{\link{VD.run}}, \code{\link{VD.run.stage}}. Introduction and examples can be found by \code{vignette("varDev")}.
}

