\name{VD.run}
\alias{VD.run}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Run a stochastic (or variable) development population model}
\description{
	Generate sequential Monte Carlo samples from a model defined by \code{VD.model}, a biologically stage-structured model with variable (or stochastic).  Results from the simulation can be compiled with \code{compile.dev.table} for subsequent calculation of population growth rate (\code{VD.solve.euler}), sensitivities, and other quantities.
}
\usage{
VD.run(VDM, stages = NULL, verbose = FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{VDM}{A \link{VD.model} object defining a variable development model and simulation controls}
  \item{stages}{Vector of stages to include.  Defaults to all stages (\code{1:numStages(VDM)}).  The vector does not need to go up to the last stage, but it should start at 1 and count up by 1's, such as \code{c(1, 2, 3) }.}
  \item{verbose}{If \code{TRUE}, verbose monitoring of simulation progress is output.  Otherwise the simulation runs silently.}
}
\details{
  \code{VD.run} sets up a sequence of calls to \code{\link{VD.run.stage}}, which actually does the simulation.  The first call to \code{\link{VD.run.stage}} generates samples of life trajectories that die in stage 1 and that survive stage 1.  The next call uses those that survive stage 1 and appends trajectories that die in stage 2 and that survive stage 2, and so on.  For stages > 1, correlated stage durations based on a Gaussian copula model are used if specified in the \code{VDM} object.
}
\value{
  An object of class \code{\link{VD.sim}}, representing variable development simulation results.
}
\references{"Stochastic development in biologically structured population models" by Perry de Valpine, to appear in Ecology in 2009.}
\author{Perry de Valpine}
\seealso{ \code{\link{VD.run.stage}}. Introduction and examples can be found by \code{vignette("varDev")}.}
