\name{VD.sim-class}
\docType{class}
\alias{VD.sim-class}
\alias{initialize,VD.sim-method}
\alias{num.stages,VD.sim-method}
\alias{simulation.summary,VD.sim-method}
\alias{simulation.summary,ANY-method}
\alias{simulation.summary-methods}
\alias{simulation.summary}

\alias{simulation.summary<-,VD.sim-method}
\alias{simulation.summary<-,ANY-method}
\alias{simulation.summary<--methods}
\alias{simulation.summary<-}

\alias{stage.names,VD.sim-method}
\alias{stageMC,VD.sim-method}
\alias{stageMC,ANY-method}
\alias{stageMC-methods}
\alias{stageMC}
\alias{stageMC<-,VD.sim-method}
\alias{stageMC<-,ANY-method}
\alias{stageMC<--methods}
\alias{stageMC<-}

\title{Class "VD.sim" }
\description{Contains sequential Monte Carlo results for a variable (or stochastic) development model of biologically stage-structured population dynamics.}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("VD.sim", VDM)}.
	 
A slightly friendlier way to create objects is given by \code{\link{VD.sim}(VDM)}. 
}
\section{Slots}{
	 \describe{
    \item{\code{simulation.summary}:}{Object of class \code{"data.frame"} containing a summary of how many simulated life schedules were run and saved for individuals dying in and surviving each stage. }
    \item{\code{stageMC}:}{Object of class \code{"list"} indexed by life stage.  \code{stageMC[[i]]} is a list, normally produced by \code{\link{VD.run.stage}}, containing simulated life trajectories of individuals who die and who survive  stage i.  \code{stageMC[[i]]} contains \code{num.alive} (an integer), \code{aliveT} (a data frame) and \code{deadT} (a data frame).  \code{aliveT} contains simulated life trajectories that survive the stage.  It has some of columns \code{dev.time} (integer stage duration), \code{dev.time.contin} (continuous stage duration), \code{Z} (marginal normal deviate used in Gaussian copula model for stage correlations),  and \code{SourceRow} (connecting row of \code{aliveT} results from the previous stage). \code{deadT} contains columns \code{DeathTime} (age-in-stage of death) and possibly \code{SourceRow} (see previous). }
    \item{\code{stage.names}:}{Vector of stage names}
    \item{\code{num.stages}:}{Integer number of stages}
  }
}
\section{Methods}{
  \describe{
    \item{initialize}{\code{signature(.Object = "VD.sim")}: ... }
    \item{num.stages}{\code{signature(VD = "VD.sim")}: Return integer number of stages. }
    \item{simulation.summary}{\code{signature(VDS = "VD.sim")}: Return simulation summary data frame. }
    \item{simulation.summary<-}{\code{signature(VDS = "VD.sim")}: Assign simulation summary data frame (intended for use by functions such as \link{VD.run.stage} that are generating simulations.) }
    \item{stage.names}{\code{signature(VD = "VD.sim")}: Return vector of stage names. }
    \item{stageMC}{\code{signature(VDS = "VD.sim")}: Return list of Monte Carlo results of simulations given death in each stage.  e.g. the i-th component of the list contains simulation results for life schedules that die in life stage i.  }
    \item{stageMC<-}{\code{signature(VDS = "VD.sim")}: Assign Monte Carlo simulation results.  Intended for use by \code{VD.run.stage}. }
	 }
}
\references{"Stochastic development in biologically structured population models" by Perry de Valpine, to appear in Ecology in 2009.}
\author{Perry de Valpine }
\seealso{
\code{\link{VD.sim}}, \code{\link{VD.run}}, \code{\link{VD.run.stage}}. Introduction and examples can be found by \code{vignette("varDev")}.
}


\keyword{classes}
