\name{calc.average.surv.rep.by.age}
\alias{calc.average.surv.rep.by.age}
\alias{calc.average.surv.rep.by.age.funcM}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Calculate the expected fecundity of individuals born now when they are at each age.   }
\description{
  Using a sequential Monte Carlo sample for a variable (or stochastic) development model, calculate for each possible age the average fecundity attained at that age (including 0 fecundity for individuals dead at that age), averaged over all life trajectories of development and mortality. This is useful for solving the Euler (or Euler-Lotka) equation for long-term population growth rate. 
}
\usage{
calc.average.surv.rep.by.age(dev.table, F = NULL, weights = NULL, use.shared.weight = TRUE, deriv.param = NULL)
calc.average.surv.rep.by.age.funcM(dev.table, F, weights = NULL, use.shared.weight = TRUE, deriv.param = NULL)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{dev.table}{ Development table produced by \code{\link{compile.dev.table}} from a \linkS4class{VD.sim} variable development simulation object. }
  \item{F}{ For \code{calc.average.surv.rep.by.age}, either an object of class \linkS4class{VD.fec}, representing fecundity in a variable development model, or a number representing constant adult fecundity per time step.  For \code{calc.average.surv.rep.by.age.funcM}, \code{m} must be an object of class \linkS4class{VD.fec}.}
  \item{weights}{ A vector matching \code{dev.table} in length with weights for each life trajectory in the sample.   These are used for calculation of derivatives, i.e. from \code{\link{VD.deriv.euler}} and should not typically be included from a command-line call.  These are \emph{not} the standard weights from the Sequential Monte Carlo simulations; those are contained in the \code{compile.dev.table} results. }
  \item{use.shared.weight}{ If \code{TRUE}, use the shared weights due to sequential Monte Carlo sampling.  This should normally be \code{TRUE}.  Ok to use in combination with \code{weights}. }
  \item{deriv.param}{ Character string naming a parameter of \code{m} with respect to which a derivative should be calculated.}
}
\details{
  The long-term (or asymptotic) population growth rate, r, is the solution to the Euler or Euler-Lotka equation:

\deqn{\sum_{z = 0}^{\infty} e^{-rz} \left[\mbox{Expected fecundity at age z} \right] = 1}{Sum over all ages z (exp[-rz] * [Expected fecundity at age z]) = 1}

These functions calculate the expected fecundity at age z for every age z.  \code{calc.average.surv.rep.by.age} is intended to be called by the user or other functions, and it calls \code{\link{calc.average.surv.rep.by.age.funcM}} to do the actual calculations.

}
\value{
  A data frame with two columns:
  \item{age}{Vector of ages for which average fecundity was calculated.  Includes the full range for which average fecundities are non-zero.}
  \item{mean.fecundity}{Average fecundity of individuals at each age.  Due to the clockwork of the model, average fecundity of individuals age z is the number of offspring produced in the parent's (z-1)-to-(z) transition that are counted when the parent is or would be age z.  It is possible that the parent died and is not counted at age z, but nevertheless had non-zero fecundity counted for its age z.  Of the possible ways to define the clockwork for a discrete-time population model, this allows a clear correspondence to the fecundity (top) row of a standard matrix population model.}
}
\references{"Stochastic development in biologically structured population models" by Perry de Valpine, to appear in Ecology in 2009.}
\author{Perry de Valpine}

\seealso{ \code{\link{euler}}, \code{\link{VD.solve.euler}}, \code{\link{compile.dev.table}}. Introduction and examples can be found by \code{vignette("varDev")}.}


