\name{calc.copula.correlations}
\alias{calc.copula.correlations}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Calculate the correlation coefficient of two stage durations that are jointly distributed according to a Gaussian copula model}
\description{
 For variable (or stochastic) development models, stage duration distributions can be correlation by a Gaussian copula in \linkS4class{VD.model} objects and simulations by \link{VD.run}.  It may be of interest to know the correlation of the development times created by the copula model.  In a variable development model, mortality may complicate interpretation of the correlations because one has to be careful about whether the correlations are conditioned on survival.  In this function, survival is set to 1 (or time-of-death to infinite), so that only the stage duration distribution is involved in the correlations.
}
\usage{
calc.copula.correlations(dist1, dist2, rho)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{dist1}{ A \linkS4class{VD.dist} object defining the first stage}
  \item{dist2}{A \linkS4class{VD.dist} object defining the second stage }
  \item{rho}{ correlation coefficient for the Gaussian copula}
}
\details{
 This constructs a \linkS4class{VD.model} object with \code{marginal.durations} of \code{dist1} and \code{dist2} and no mortality.
}
\value{
  A list with components
  \item{cor.norm }{Correlation of the standard normal deviates simulated for the correlated stages.  This should be \code{rho} (within sampling error) or something is wrong.}
  \item{cor.dev.time }{Correlation in the integer development times (stage durations).}
  \item{cor.dev.time.contin}{Correlation in the continuous deviates (if applicable) that were rounded up to get the integer development times.}
}
\references{"Stochastic development in biologically structured population models" by Perry de Valpine, to appear in Ecology in 2009.}
\author{ Perry de Valpine}
\seealso{ Introduction and examples can be found by \code{vignette("varDev")}. }

