\name{compile.dev.table}
\alias{compile.dev.table}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Compile a development table from sequential Monte Carlo simulations of a variable (stochastic) development model. }
\description{
  The sequential Monte Carlo simulations are originally generated in a compact form, with stage durations or ages-within-stage of death in a table that also includes the row number of the previous stage's simulation, which contains a row number of the previous stage's simulation, etc.  This function pulls the simulations together into a more comprehensible table, which is needed for subsequent analysis such as \code{\link{calc.average.surv.rep.by.age}}. 
}
\usage{
compile.dev.table(VDS, final.stage = NULL, init.stage = 1, total.age = TRUE, include.dev = TRUE, include.contin = FALSE, include.Z = FALSE, survivors = FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{VDS}{ An object of class \linkS4class{VD.sim} representing sequential Monte Carlo simulation results of a variable development model. }
  \item{final.stage}{ Integer value of the final stage requested in the development table. }
  \item{init.stage}{ Initial stage to begin compiling the development table.  If this is not 1, results should be interpreted with caution. }
  \item{total.age}{ If \code{TRUE}, return \emph{total ages} at which each stage transition occurs.  If \code{FALSE}, return \emph{ages-within-stages} at which each stage transition occurs. } 
  \item{include.dev}{ If \code{TRUE}, return the development table (in format specificed by \code{total.age})}
  \item{include.contin}{If \code{TRUE}, return a table of the continuous development times that may have been rounded up to get the integer development times.  This always returns \emph{ages-within-stages, not total ages}. }
  \item{include.Z}{ If \code{TRUE}, return a table of the standard normal deviates that match the continuous development times in quantiles of the multivariate normal distribution used for a Gaussian copula.}
  \item{survivors}{ If \code{TRUE}, the table is made of individuals who \emph{survive} the chosen \code{final.stage}. If \code{FALSE}, the table is made of individuals who \emph{die} in the chosen \code{final.stage}.  Since everyone who survives the last possible stage dies, \code{survivors} should be \code{FALSE} when \code{final.stage} is the last possible stage, i.e. \code{num.stages(VDS)}, and may be \code{TRUE} or \code{FALSE} for other stages. }
}
\details{
  This is a workhorse function to turn variable development simulation results into more useable forms.
}
\value{
  A list with components:
  \item{dev.table }{The development table (if requested) of either total ages or ages-within-stages, given as integers. }
  \item{dev.table.contin }{The development table (if requested) of ages-within-stages, given as real numbers, even though the actual variable development model uses discrete time steps.}
  \item{dev.table.Z}{The table (if requested) of standard normal deviates used for the Gaussian copula for correlated stage durations.}
  \item{survival.weight}{Simulation estimate of dying in stage \code{final.stage}.}
  \item{stage.kept.weight}{Total number of recorded simulations / number of simulations terminating the in the requested stage and alive-or-dead status.}
  \item{shared.weight}{survival.weight * stage.kept.weight. For Monte Carlo averages over the full sequential Monte Carlo sample, this is the weight of every life trajectory in the requested category of \code{final.stage} and alive-or-dead status.}
   \item{MC.sample.size.final.stage}{Number of Monte Carlo samples for stage \code{final.stage}, either alive or dead as chosen.}
   \item{MC.sample.size.all}{Total Monte Carlo sample size of \code{VDS}.}
}
\references{"Stochastic development in biologically structured population models" by Perry de Valpine, to appear in Ecology in 2009.}
\author{Perry de Valpine}
\seealso{ \link{calc.average.surv.rep.by.age}, \link{VD.run}, \link{VD.run.stage}. Introduction and examples can be found by \code{vignette("varDev")}.  }

