\name{lfraction.maturing.at.SASD.independent}
\alias{lfraction.maturing.at.SASD.independent}
\alias{VD.solve.fraction.maturing.at.SASD.independent}

%- Also NEED an '\alias' for EACH other topic documented here.
\title{Calculate and optimize the fraction of a stage maturing at stable age-stage distribution of a variable development model}
\description{
  At the stable age-stage distribution of a stochastic (or variable) development model, a fixed fraction of individuals in a stage mature at the next time step, of those who survive to the next time step.  For determining what stochastic development models give the same stable stage distribution and same fractions maturing and dying from each stage at each time step, one can pick a family of distributions for a stage duration that has a free parameter that can be chosen to match the desired fraction maturing.  \code{lfraction.maturing.at.SASD.independent} calculate the log fraction for the case of independent stage durations. \code{VD.solve.fraction.maturing.at.SASD.independent} function finds the value of a model parameter that makes the fraction maturing match a given value.
}
\usage{
lfraction.maturing.at.SASD.independent(VD.dist.dev, VD.dist.surv, r = 0, subtract.val = 0, max.age = NULL, VD.dist.dev.replace = NULL)
VD.solve.fraction.maturing.at.SASD.independent(VD.dist.dev, VD.dist.surv, r, fraction.maturing, param, range, max.age = NULL, details = FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{VD.dist.dev}{An object of class \code{\link{VD.dist}} defining the stage duration distribution}
  \item{VD.dist.surv}{An object of class \code{\link{VD.dist}} defining the mortality distribution}
  \item{r}{Long-term population growth rate, typically obtained from \code{\link{VD.solve.euler}}}
  \item{subtract.val}{A constant value to be subtracted from the log fraction maturing.  This facilitates solving for a desired log fraction maturing using \code{\link{uniroot}}, as in \code{\link{VD.solve.fraction.maturing.at.SASD.independent}}}.
  \item{fraction.maturing}{ The desired fraction of the stage maturing, given survival, at each time step under the stable age-stage distribution.  \code{VD.solve.fraction.maturing.at.SASD.independent} finds parameter values such that the model gives the \code{fraction.maturing}. }
  \item{param}{ String naming the parameter of \code{VD.dist.surv} that should be searched to match the \code{fraction.maturing}. }
  \item{range}{ A vector of length 2 giving the minimum and maximum values for finding the solution for \code{param}. }
 \item{max.age}{The maximum age-within-stage to consider in summing maturing and surviving individuals.  If \code{NULL}, the lesser of the 0.9999 quantiles for the development and survival distributions will be used.  For repeated calls such as from  \code{\link{VD.solve.fraction.maturing.at.SASD.independent}}, there are two advantages to specifiying \code{max.age}: it is more efficient not to calculate it on each call, and it keeps the root finding problem smooth by not having the range of the sum change for different values of whatever parameter is being varied. }
  \item{VD.dist.dev.replace}{ An optional list with names that are parameter names of \code{VD.dist.dev} and values that are the values to be used for corresponding parameters.  Allowing parameters to be changed in this way facilitates calls to \code{lfraction.maturing.at.SASD.independent} from \code{VD.solve.fraction.maturing.at.SASD.independent}.  See \code{VD.dist.calc}. }
  \item{details}{If TRUE, return the object returned by \code{\link{uniroot}}.  Otherwise (default) just return the root.}
}
\details{
  For the case of  constant survival per time step, these calculations are equivalent to equation 6.111 of Caswell (2001).
}
\value{
  For \code{lfraction.maturing.at.SASD.independent}, a number giving the log fraction maturing minus the \code{subtract.val}.

For  \code{VD.solve.fraction.maturing.at.SASD.independent}, the value of parameter \code{param} that leads to the desired \code{fraction.maturing}.
}
\references{"Stochastic development in biologically structured population models" by Perry de Valpine, to appear in Ecology in 2009.}
\author{Perry de Valpine}
\seealso{\link{lfraction.maturing.at.SASD.mc}, \link{VD.solve.fraction.maturing.at.SASD.mc}. Introduction and examples can be found by \code{vignette("varDev")}. }

