\name{lfraction.maturing.at.SASD.mc}
\alias{lfraction.maturing.at.SASD.mc}
\alias{lfraction.maturing.at.SASD.mc.dev.only}
\alias{VD.solve.fraction.maturing.at.SASD.mc}

%- Also NEED an '\alias' for EACH other topic documented here.

\title{ Calculate and optimize the fraction maturing given survival at each time step of a variable development model allowing correlations among stage durations}
\description{
 At the stable age-stage distribution of a stochastic (or variable) development model, a fixed fraction of individuals in a stage mature at the next time step, of those who survive to the next time step.  For determining what stochastic development models give the same stable stage distribution and same fractions maturing and dying from each stage at each time step, one can pick a family of distributions for a stage duration that has a free parameter that can be chosen to match the desired fraction maturing.  \code{lfraction.maturing.at.SASD.mc} and \code{lfraction.maturing.at.SASD.mc.dev.only} calculate the log fraction. \code{VD.solve.fraction.maturing.at.SASD.mc} finds the value of a model parameter that makes the fraction maturing match a given value.  These methods use sequential Monte Carlo simulations to allow correlated stage durations.
}
\usage{
lfraction.maturing.at.SASD.mc(VDM, VD.dist.dev, r, marg.cum, death.time, age.prev, replace.param, max.age, subtract.val = 0)
lfraction.maturing.at.SASD.mc.dev.only(VDM, VD.dist.dev, r, marg.cum, h.surv, age.prev, replace.param, age.vector, subtract.val = 0)
VD.solve.fraction.maturing.at.SASD.mc(VDM, iStage = -1, VD.dist.dev, VD.dist.surv, r, fraction.maturing, param, range, n = 10000, max.age = NULL, details = FALSE, mc.dev.only = FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{VDM}{ Variable development model of class \linkS4class{VD.model} }
  \item{iStage}{Integer index of the stage for which the stage duration model should be solved}
  \item{VD.dist.dev}{ stage duration distribution of class \linkS4class{VD.dist} for the next stage, i.e. the stage for which the log fraction maturing is requested }
  \item{VD.dist.surv}{Survival (age-within-stage of death) distribution of class \linkS4class{VD.dist} for the next stage.}
  \item{r}{ Population growth rate, i.e. solution to the Euler equation obtained by \code{\link{VD.solve.euler}} }
  \item{fraction.maturing}{The desired fraction maturing}
  \item{param}{Character string of the name of the parameter of \code{VD.dist.dev} that should be searched for a value to obtain \code{fraction.maturing}}
  \item{range}{Vector of 2 numbers giving the min and max of the range to search for \code{param}}
  \item{n}{Monte Carlo sample size to use for the final stage}
  \item{details}{If \code{TRUE}, \code{VD.solve.fraction.maturing.at.SASD.mc} returns the object returned by its call to \code{\link{uniroot}}.  Otherwise it returns the solution value of the \code{param}.}
  \item{mc.dev.only}{If \code{TRUE}, the Monte Carlo will be used for the stage duration only, not the survival, i.e. \code{lfraction.maturing.at.SASD.mc.dev.only} will be used, not \code{lfraction.maturing.at.SASD.mc}.}
  \item{marg.cum}{ Vector of quantiles (cumulative probabilities) for the stage durations of the next stage }
  \item{death.time}{ Vector of ages-within-stage of death }
  \item{age.prev}{ Vector of ages of the previous stage transition }
  \item{replace.param}{ Optional list with names matching parameters if \code{VD.dist.dev} and values to be plugged in for the corresponding parameters.  Facilitates calling this function by \code{\link{VD.solve.fraction.maturing.at.SASD.mc}} }
  \item{max.age}{ Maximum age to consider in summations. }
  \item{subtract.val}{ A constant value to be subtracted from the log fraction maturing, faciliting calls from \link{uniroot}}
  \item{h.surv}{Vector of probabilities that death occurs at greater than or equal to each age in \code{age.vector} }
\item{age.vector}{Vector of ages over which summations should be done}
}
\details{
\code{lfraction.maturing.at.SASD.mc} works entirely by Monte Carlo integration.  Its method for Monte Carlo summation is similar to that in \code{\link{make.SASD}}.

\code{lfraction.maturing.at.SASD.dev.only} uses Monte Carlo samples of development times but direct calculation of survival probabilities, allowing a more accurate result.

\code{VD.solve.fraction.maturing.at.SASD.mc} finds the value of a parameter that gives the desired fraction maturing.
}
\value{
For \code{lfraction.maturing.at.SASD.mc} and \code{lfraction.maturing.at.SASD.dev.only}, the log fraction maturing.

For \code{VD.solve.fraction.maturing.at.SASD.mc}, the value of the parameter giving the desired fraction maturing.
}
\seealso{\link{lfraction.maturing.at.SASD.independent}, \link{VD.solve.fraction.maturing.at.SASD.independent} for independent stage durations. Introduction and examples can be found by \code{vignette("varDev")}.}
\references{"Stochastic development in biologically structured population models" by Perry de Valpine, to appear in Ecology in 2009.}
\author{ Perry de Valpine}

