\name{varDev-package}
\alias{varDev-package}
\alias{varDev}
\docType{package}
\title{
Package for variable or stochastic development models of biologically stage-structured population dynamics
}
\description{
Matrix population models are limited in their ability to accommodate variation in stage durations.  This package allows demographic analysis of stage-structured dynamics where each stage can have a distribution of stage durations (development times), which may be correlated, and a distribution of age-within-stage of death (mortality).  Demographic analysis includes long-term population growth rate, stable age-stage distribution, and sensitivities obtained by sequential Monte Carlo numerical integration.
}
\details{
\tabular{ll}{
Package: \tab varDev\cr
Type: \tab Package\cr
Version: \tab 0.5\cr
Date: \tab 2008-10-16\cr
License: \tab GPL version 2.0 or greater\cr
LazyLoad: \tab yes\cr
Depends: \tab methods\cr
}
Models are defined with VD.model.  Distributions are defined by \link{VD.dist}.  Sequential Monte Carlo simulations are run by \link{VD.run}.  Stable age-stage distribution is obtained by \link{make.SASD}.  Long-term growth rate is obtained by \link{VD.solve.euler}.  Derivatives of long-term growth rate with respect to model parameters are obtained by \link{VD.deriv.growth.rate}.
}
\author{
Perry de Valpine

Maintainer: Perry de Valpine <pdevalpine@berkeley.edu>
}
\references{"Stochastic development in biologically structured population models" by Perry de Valpine, to appear in Ecology in 2009.}

\keyword{ package }

\seealso{ Introduction and examples can be found by \code{vignette("varDev")}. }